@@ -46,12 +46,12 @@ public:
         return m_result;
     }
     void setCreateProblems(bool v);
-    void setOffset(const KDevelop::SimpleCursor offset);
+    void setOffset(const KDevelop::CursorInRevision& offset);
 
     virtual void visitNode(AstNode *node);
 
 protected:
-    KDevelop::Declaration* processVariable(VariableIdentifierAst *variable);
+    KDevelop::DeclarationPointer processVariable( VariableIdentifierAst* variable);
 
     void visitAssignmentExpression(AssignmentExpressionAst *node);
     virtual void visitBaseVariable(BaseVariableAst* node);
@@ -77,13 +77,13 @@ protected:
     KDevelop::QualifiedIdentifier identifierForNode(VariableIdentifierAst* id);
 
 
-    virtual void usingDeclaration(AstNode* node, KDevelop::Declaration* decl) {
+    virtual void usingDeclaration(AstNode* node, const KDevelop::DeclarationPointer& decl) {
         Q_UNUSED(node) Q_UNUSED(decl)
     }
 
-    KDevelop::Declaration* findDeclarationImport(DeclarationType declarationType, IdentifierAst* node);
-    KDevelop::Declaration* findDeclarationImport(DeclarationType declarationType, VariableIdentifierAst* node);
-    KDevelop::Declaration* findDeclarationImport(DeclarationType declarationType, AstNode* node, const KDevelop::QualifiedIdentifier& identifier);
+    KDevelop::DeclarationPointer findDeclarationImport(DeclarationType declarationType, IdentifierAst* node);
+    KDevelop::DeclarationPointer findDeclarationImport(DeclarationType declarationType, VariableIdentifierAst* node);
+    KDevelop::DeclarationPointer findDeclarationImport(DeclarationType declarationType, AstNode* node, const KDevelop::QualifiedIdentifier& identifier);
 
 protected:
     EditorIntegrator* m_editor;
@@ -94,7 +94,7 @@ private:
     void buildNamespaceUses(NamespacedIdentifierAst* namespaces, const KDevelop::QualifiedIdentifier& identifier);
 
     bool m_createProblems;
-    KDevelop::SimpleCursor m_offset;
+    KDevelop::CursorInRevision m_offset;
     KDevelop::DUContext* m_currentContext;
 
     ExpressionEvaluationResult m_result;
